import { useEffect, useState } from "react";
import { PageHeading } from "@src/components/common/headings/pageHeading";
import { TodoList } from "@src/components/todos";
import * as signalR from "@microsoft/signalr";
import { HubConnection } from "@microsoft/signalr";
import { Todo } from "@src/core/entities/todo";

const HomePage = () => {
  const [conn, setConn] = useState<HubConnection>();
  const [todos, setTodos] = useState<Todo[]>([]);

  useEffect(() => {
    const connection = new signalR.HubConnectionBuilder()
      .withUrl("http://localhost:5000/hubs/todo")
      .build();

    connection.on("todos", (todos) => {
      const parsedTodos = JSON.parse(todos);
      setTodos(parsedTodos);
    });

    connection.start().then(() => connection.invoke("GetTodos"));

    setConn(connection);
  }, []);

  return (
    <main className="py-8 px-14 space-y-6">
      <section className="space-y-2">
        <PageHeading title="Inbox" />
        <TodoList todos={todos} conn={conn} />
      </section>
    </main>
  );
};
export default HomePage;
